@@ -773,6 +773,48 @@ FieldEntry::set_position_vfunc(int position) // IN: The new position
 }
 
 
+/*
+ *-----------------------------------------------------------------------------
+ *
+ * view::FieldEntry::on_size_request --
+ *
+ *      Overridden virtual function to set the minimum size for the widget.
+ *
+ * Results:
+ *      None.
+ *
+ * Side effects:
+ *      None.
+ *
+ *-----------------------------------------------------------------------------
+ */
+
+void
+FieldEntry::on_size_request(Gtk::Requisition* requisition) // OUT:
+{
+   /*
+    * This hack will only work when width_chars is -1 internal to the GtkEntry.
+    * In order to ensure that, we temporarily save and replace it.
+    */
+   GtkEntry* entry = GTK_ENTRY(gobj());
+   int width_chars = entry->width_chars;
+   entry->width_chars = -1;
+   DeadEntry::on_size_request(requisition);
+
+   /*
+    * The "150" magic number is the MIN_ENTRY_WIDTH value from inside
+    * gtkentry.c.  This lets us pull out the border size without duplicating
+    * all of the hairy calculations that GtkEntry does internally.
+    */
+
+   int border = requisition->width - 150;
+   ComputeLayout();
+   requisition->width = mMaxTextWidth + border;
+
+   entry->width_chars = width_chars;
+}
+
+
 /*
  *-----------------------------------------------------------------------------
  *
@@ -845,6 +887,16 @@ FieldEntry::ComputeLayout()
               break;
       }
 
+      /*
+       * Right-aligned entries have tabs before each field, Left-aligned ones
+       * have tabs after each, and center-aligned fields have tabs both before
+       * and after.
+       *
+       * Left: XX\t-XX\t-XX\t
+       * Right: \tXX-\tXX-\tXX
+       * Center: \tXX\t-\tXX\t-\tXX\t
+       */
+
       if (fieldOffset != offset) {
          mMarkedUp += sTabChar;
          mTabs.set_tab(tabIndex, Pango::TAB_LEFT, fieldOffset);
@@ -871,6 +923,8 @@ FieldEntry::ComputeLayout()
          mMarkedUp += mDelim;
          offset += delimWidth;
       }
+
+      mMaxTextWidth = offset;
    }
 
    /* Resize in case we have used less tab stops than the max. */
